@@ -412,6 +412,7 @@ class Config:
                 | filter
                 | each
                 | macro
+                | call
                 | raw
             """
             + self.custom_blocks
@@ -527,6 +528,7 @@ class Config:
             | verbatim
             | each
             | macro
+            | call
             | raw
             """
             + self.custom_blocks
@@ -568,12 +570,16 @@ class Config:
             | endmacro
             | raw
             | endraw
+            | call
+            | endcall
             """
             + self.custom_blocks
             + r"""
         """
         )
-
+        self.template_blocks: str = r"""
+        {%((?!%}).)+%}
+        """
         self.ignored_blocks: str = r"""
               <(pre|textarea).*?</(\1)>
             | <(script|style).*?(?=(\</(?:\3)>))
